@@ -4,8 +4,10 @@ use strict;
 use warnings;
 use 5.010;
 
+no if $] >= 5.018, warnings => "experimental::smartmatch";
+
 use Carp qw(cluck);
-use Encode qw(decode);
+use Encode qw(decode encode);
 use Travel::Routing::DE::VRR::Route;
 use LWP::UserAgent;
 use XML::LibXML;
@@ -37,7 +39,7 @@ use Exception::Class (
 	},
 );
 
-our $VERSION = '2.01';
+our $VERSION = '2.04';
 
 sub set_time {
 	my ( $self, %conf ) = @_;
@@ -234,6 +236,9 @@ sub place {
 		);
 	}
 
+	$place = encode( 'ISO-8859-15', $place );
+	$stop  = encode( 'ISO-8859-15', $stop );
+
 	$type //= 'stop';
 
 	@{ $self->{post} }{ "place_${which}", "name_${which}" } = ( $place, $stop );
@@ -411,6 +416,7 @@ sub submit {
 	my ( $self, %conf ) = @_;
 
 	$self->{ua} = LWP::UserAgent->new(%conf);
+	$self->{ua}->env_proxy;
 
 	my $response = $self->{ua}
 	  ->post( 'http://efa.vrr.de/vrr/XSLT_TRIP_REQUEST2', $self->{post} );
@@ -683,7 +689,7 @@ Travel::Routing::DE::VRR - unofficial interface to the efa.vrr.de German itinera
 
 =head1 VERSION
 
-version 2.01
+version 2.04
 
 =head1 DESCRIPTION
 
@@ -836,7 +842,7 @@ Travel::Routing::DE::VRR::Exception(3pm) object.
 
 =head1 BUGS AND LIMITATIONS
 
-It is best not to pass Unicode characters to B<Travel::Routing::DE::VRR>.
+None known.
 
 =head1 SEE ALSO
 
@@ -846,11 +852,13 @@ It is best not to pass Unicode characters to B<Travel::Routing::DE::VRR>.
 
 =item * Travel::Routing::DE::VRR::Route(3pm)
 
+=item * L<WWW::EFA> is another implementation, using L<Moose>.
+
 =back
 
 =head1 AUTHOR
 
-Copyright (C) 2009-2011 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
+Copyright (C) 2009-2014 by Daniel Friesel E<lt>derf@finalrewind.orgE<gt>
 
 =head1 LICENSE
 
